This document contains the Spec2nii release history in reverse chronological order.

0.6.10 (Monday 10th July 2023)
------------------------------
- Stop tests being vendered as a top-level package. Bug introduced in `0.6.9`.

0.6.9 (Friday 7th July 2023)
----------------------------
- Add handling for the `fidall` sequence in GE.
- Add handling for the `slaser` sequence in GE.
- Update to nifti-mrs-tools 1.0.0 API.
- Minor code fixes contributed by the community.

0.6.8 (Wednesday 22nd March 2023)
---------------------------------
- Added handling for the GE jpress sequence (for JH HURCULES sequence)
- Added twix handling of the HYPER (smm_svs_herc_hyper) sequence (added by Aaron Gudmundson)
- Better handling of partial acqusitions of Siemens and Philips HYPER sequence.

0.6.7 (Wednesday 15th March 2023)
---------------------------------
- `spec2nii insert` can now insert a compliant header object into a non-compliant NIfTI file to generate a new NIfTI-MRS file.
- `spec2nii insert` can now update dwelltime using the optional `--dwelltime` argument.

0.6.6 (Thursday 9th March 2023)
-------------------------------
- Added in ability to generate empty NIfTI-MRS for twix-pathway MRSI scans.

0.6.5 (Wednesday 8th February 2023)
-----------------------------------
- Fixed bug in philips and rda metadata translation functions.

0.6.4 (Tuesday 7th February 2023)
---------------------------------
- Added first pass at new `spec2nii auto` feature with automatic conversion for some formats.

0.6.3 (Monday 6th February 2023)
--------------------------------
- Added handling for GE presscsi and probe-s sequences.

0.6.2 (Sunday 5th February 2023)
----------------------------------
- Handle HYPER references in SPAR/SDAT pipeline
- Handle HURCULES/HERMES (smm_svs_herc) sequence in XA twix format.
- Changed behaviour of Siemens DICOM `spec2nii dicom` to recursively glob directory argument.
- Better error output when encountering MR Image SOPClassUID.

0.6.1 (Wednesday 18th January 2023)
-----------------------------------
- Fixed conjugation issue introduced by new nifti-mrs package dependency
- SPAR/SDAT pipeline now handles HYPER special case.
- Data/list pipeline now handles HYPER special case.
- Fixed issue with XA Twix PatientSex and TxOffset attributes.
- Reenable Bruker conversion. 

0.6.0 (Wednesday 11th January 2023)
-----------------------------------
- NIfTI-MRS creation/handling/verification now performed by nifti-mrs package.

0.5.0 (Friday 2nd December 2022)
--------------------------------
- NIfTI-MRS version 0.6
- Handle locale specific decimal separators in rda format.
- Added special-case handling of the mgs_svs_ed(_universal) for twix data inputs.
- Modified repository structure. Siemens and Philips files now have dedicated directories.
- Support Python 3.11
- Enable automatic Pypi upload and move to pyproject.toml file build.
- Bruker conversion currently limited to numpy installations <1.20.0. Awaiting brukerapi package update.

0.4.9 (Friday 4th November 2022)
--------------------------------
- Handle FID sequence in twix converter.
- Code lint updates
- Updated versioneer.

0.4.8 (Sunday 2nd October 2022)
-------------------------------
- Updated citation information with publication of NIfTI-MRS paper.
- Updated README information.
- Added check that file had been written successfully.
- Minor under the hood changes

0.4.7 (Sunday 11th September 2022)
----------------------------------
- Add tests for previous Siemens SOP UID DICOM types from VB line scanners.
- Fixed bug in Siemens RDA header read. Still no orientation tests for RDA format.
- Siemens VX line dicom files will now sum arrays of TE values.
- Added better ID of the Siemens implementation of the standardised SLASER sequence (as DICOM).
- Added provisional support for the GE slaser_cni sequence.
- Added handling of LCModel RAW files lacking header information.
- Included code and spelling fixes kindly contributed by Dimitri Papadopoulos

0.4.6 (Friday 8th July 2022)
----------------------------
- Fix GE p file incorrect TR and TE. Were expressed in microseconds.

0.4.5 (Friday 8th July 2022)
----------------------------
- Improved handling of Siemens DICOM files. Now explicitly handle Siemens Syngo Non Image Storage or MRSpectroscopyStorage DICOM types, regardless of scanner baseline.

0.4.4 (Thursday 28th April 2022)
--------------------------------
- Improved handling of Philips enhanced DICOM
- WIP handling of Philips classic DICOM, more test data required.
- SPAR/SDAT Philips data can now be reshaped ont eh command line using the -s and -t commands.
- Corrected phase convention for Siemens NumarisX (XA) line DICOM data. This was reversed (conjugated) compared to VX line.
